==> openshift-model-config-6.2.0-sources.jar: io/fabric8/openshift/api/model/config/v1/UpdateHistoryFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface UpdateHistoryFluent<A extends UpdateHistoryFluent<A>> extends Fluent<A>{
  public String getAcceptedRisks();
  public A withAcceptedRisks(String acceptedRisks);
  public Boolean hasAcceptedRisks();
  public String getCompletionTime();
  public A withCompletionTime(String completionTime);
  public Boolean hasCompletionTime();
  public String getImage();
  public A withImage(String image);
  public Boolean hasImage();
  public String getStartedTime();
  public A withStartedTime(String startedTime);
  public Boolean hasStartedTime();
  public String getState();
  public A withState(String state);
  public Boolean hasState();
  public Boolean getVerified();
  public A withVerified(Boolean verified);
  public Boolean hasVerified();
  public String getVersion();
  public A withVersion(String version);
  public Boolean hasVersion();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public A withVerified();
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/UpdateHistoryFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface UpdateHistoryFluent<A extends UpdateHistoryFluent<A>> extends Fluent<A>{
  public String getAcceptedRisks();
  public A withAcceptedRisks(String acceptedRisks);
  public Boolean hasAcceptedRisks();
  public String getCompletionTime();
  public A withCompletionTime(String completionTime);
  public Boolean hasCompletionTime();
  public String getImage();
  public A withImage(String image);
  public Boolean hasImage();
  public String getStartedTime();
  public A withStartedTime(String startedTime);
  public Boolean hasStartedTime();
  public String getState();
  public A withState(String state);
  public Boolean hasState();
  public Boolean getVerified();
  public A withVerified(Boolean verified);
  public Boolean hasVerified();
  public String getVersion();
  public A withVersion(String version);
  public Boolean hasVersion();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public A withVerified();
  
}
